# Kimino

Kimino is a TUI app. Which helps to create, custom app desktop entry in Linux.

# Preview

# Features

**1. Supports online web app (suppose : Youtube web app)**
**2. Bash file app (it runs the bash file)**
**3. TUI or GUI app (it aks for the command for ruining the app, like : `Kimino`)**
**4. Supports all Linux distro, all terminal apps**
**_much more!_**


# Installation (Windows, Linux, Mac OS)

**Installation or update with `uv`:**

```
uv tool install -U git+https://github.com/TheAhumMaitra/Kimino.git
```

**_Done , now launch with just ``Kimino` command_**

**Manual installation:**

**Pre-requirements : `python` installed**
**\*Note : It can work on older Python version but it is not recommended.**

**_Steps :_**

1. Clone this repo

```
git clone https://github.com/TheAhumMaitra/Kimino.git
```

2. Go to the `Kimino` folder

It's saved where you cloned this repo

```
cd Kimino
```

3. Install it

```
pip install .
```

**_Done , now launch with just `Kimino` command_**


# License

[`GPL-3.0-or-later`](LICENSE)
